Module: Fastlane::Helper::RustoredOptions

Defined in:
lib/fastlane/plugin/rustored/helper/rustored_options.rb

Class Method Summary collapse

Class Method Details

.common_optionsObject



6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
# File 'lib/fastlane/plugin/rustored/helper/rustored_options.rb', line 6

def self.common_options
  [
    FastlaneCore::ConfigItem.new(
      key: :key_id,
      env_name: "RUSTORE_KEY_ID",
      description: "The key id for authenticating with RuStore",
      optional: false,
      type: String
    ),
    FastlaneCore::ConfigItem.new(
      key: :private_key,
      env_name: "RUSTORE_PRIVATE_KEY",
      description: "The private key for authenticating with RuStore",
      optional: false,
      type: String,
      sensitive: true,
      display_in_shell: false
    ),
    FastlaneCore::ConfigItem.new(
      key: :package_name,
      env_name: "RUSTORE_PACKAGE_NAME",
      description: "The package name of the app you want to publish",
      optional: false,
      type: String
    ),
    FastlaneCore::ConfigItem.new(
      key: :version_id,
      env_name: "RUSTORE_VERSION_ID",
      description: "The version id of the app you want to publish",
      optional: false,
      type: Integer
    )
  ]
end