Module: Fastlane::Helper::RustoredOptions

Defined in:
lib/fastlane/plugin/rustored/helper/rustored_options.rb

Class Method Summary collapse

Class Method Details

.common_optionsObject



6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
# File 'lib/fastlane/plugin/rustored/helper/rustored_options.rb', line 6

def self.common_options
  [
    FastlaneCore::ConfigItem.new(
      key: :token,
      env_name: "RUSTORE_TOKEN",
      description: "The token for authenticating with RuStore",
      optional: false,
      type: String
    ),
    FastlaneCore::ConfigItem.new(
      key: :package_name,
      env_name: "RUSTORE_PACKAGE_NAME",
      description: "The package name of the app you want to publish",
      optional: false,
      type: String
    ),
    FastlaneCore::ConfigItem.new(
      key: :version_id,
      env_name: "RUSTORE_VERSION_ID",
      description: "The version id of the app you want to publish",
      optional: false,
      type: Integer
    )
  ]
end